Learn R Programming

nimblewomble (version 0.1.0)

gamma1n2.mcov2: Cross-covariance terms for the posterior distribution of wombling measures for Matern \(\nu=5/2\), the squared exponential kernel.

Description

For internal use only. Performs one-dimensional quadrature using integral as a limit of a sum.

Usage

gamma1n2.mcov2(coords, t, u, s0, phi)

Value

A matrix of cross-covariance terms. For internal use only.

Arguments

coords

coordinates

t

value of t

u

vector of u

s0

starting point on curve \(s_0\)

phi

posterior sample of \(\phi\)

Author

Aritra Halder <aritra.halder@drexel.edu>,
Sudipto Banerjee <sudipto@ucla.edu>

Examples

Run this code
if (FALSE) {
#####################
# Internal use only #
#####################
# Example usage inside nimblewomble::wombling_matern2(...)
gamma1n2.mcov2(coords = coords[1:ncoords, 1:2], t = tvec[j],
               u = umat[j, 1:2], s0 = curve[j, 1:2], phi = phi[i])
}

Run the code above in your browser using DataLab